CodeAddLinesBuilder

Struct CodeAddLinesBuilder 

pub struct CodeAddLinesBuilder { /* private fields */ }
Builder for an animation of adding code lines to the code block.

               code.add_lines()
                   .str(
                       r"
fn fib(n: u32) -> u32 {
   match n {
       0 => 0,
       1 => 1,
       _ => fib(n - 1) + fib(n - 2),
   }
}
               "
                   )
                   .over(5.s())
                   .style(CodeAnimationStyle::TypeWriter),

Implementations

Source

impl CodeAddLinesBuilder

pub fn str(self, text: impl Into<String>) -> Self

Value of the lines that you want to add

pub const fn from_line(self, line: usize) -> Self

Line number that you want to start adding newlines from

pub const fn over(self, duration: Time) -> Self

Duration that you want to be animating adding newlines over

pub const fn ease(self, ease: Ease) -> Self

Ease function that you want to use on this animation

pub const fn style(self, style: CodeAnimationStyle) -> Self

Style of the adding code animation