CodeRemoveLinesBuilder

Struct CodeRemoveLinesBuilder 

pub struct CodeRemoveLinesBuilder { /* private fields */ }
Builder for an animation of removing lines from a code block.

               code.remove_lines()
                   .range(0..25)
                   .over(5.s())
                   .style(CodeAnimationStyle::TypeWriter),

Implementations

Source

impl CodeRemoveLinesBuilder

pub const fn range(self, range: Range<u32>) -> Self

Range of lines that you want to remove

pub const fn over(self, duration: Time) -> Self

Duration that you want to be animating the removal over

pub const fn ease(self, ease: Ease) -> Self

Ease function that you want to use on this animation

pub const fn style(self, style: CodeAnimationStyle) -> Self

Style of the code animation