PlaySoundBuilder

Struct PlaySoundBuilder 

pub struct PlaySoundBuilder { /* private fields */ }
Builder for an animation of playing a sound effect.

               sfx()
                   .path("./click.mp3")
                   .play()
                   .after(0.5.s()),

Implementations

Source

impl PlaySoundBuilder

pub fn after(self, delay: Time) -> AnimOP

Delay before the sound starts playing, relative to when the animation is triggered

pub fn delay(self, delay: Time) -> AnimOP

Delay before the sound starts playing