CircleHandle

Struct CircleHandle 

pub struct CircleHandle(pub Uuid);
Handle to a Circle sub-object of a code window, for use in animation builders.

Tuple Fields

0: Uuid

Implementations

Source

impl CircleHandle

pub const fn position(&self) -> PositionBuilder

Returns a builder for an animation that moves this object to a target position.

               handle.position()
                   .to(Vec2::new(100.0, 200.0))
                   .over(5.s())
                   .ease(Ease::InOutCubic),
pub const fn scale(&self) -> ScaleBuilder

Returns a builder for an animation that scales this object.

               handle.scale()
                   .to(Vec2::new(2.0, 2.0))
                   .over(5.s())
                   .ease(Ease::InOutCubic),
pub const fn rotation(&self) -> RotateBuilder

Returns a builder for an animation that rotates this object.

               handle.rotation()
                   .to(360.0)
                   .over(5.s())
                   .ease(Ease::InOutCubic),