CodeHandle

Struct CodeHandle 

pub struct CodeHandle(pub AnimObj);
Wrapper around the AnimObj struct that allows for clean animation construction for specific AnimObj kind.

Tuple Fields

0: AnimObj

Implementations

Source

impl CodeHandle

pub fn instantiate(&self) -> AnimOP

Returns an animation that instantly adds that object to the scene.

let pointer = svg()
    .path("./pointer-tool.svg")
    .build();
Project {
   scene_settings,
   timeline: timeline![
       cw.instantiate(),
    ]
}
pub const fn add_lines(&self) -> CodeAddLinesBuilder

Returns a builder for an animation of adding code lines to the code block.

               code.add_lines()
                   .str(
                       r"
fn fib(n: u32) -> u32 {
   match n {
       0 => 0,
       1 => 1,
       _ => fib(n - 1) + fib(n - 2),
   }
}
               "
                   )
                   .over(5.s())
                   .style(CodeAnimationStyle::TypeWriter),
pub const fn modify_line(&self) -> CodeModifyLineBuilder

Returns a builder for an animation of modifying a line of code.

               code.modify_line()
                   .str("New Line Contents")
                   .line(25)
                   .over(5.s())
                   .style(CodeAnimationStyle::TypeWriter),
pub fn highlight(&self) -> CodeHighlightBuilder

Returns a builder for an animation of highlighting code by line range or regex pattern.

               code.highlight()
                   .lines(3..6)
                   .color(Color::new(1.0, 1.0, 0.0, 0.3))
                   .over(1.s())
                   .ease(Ease::InOutCubic),
pub const fn remove_lines(&self) -> CodeRemoveLinesBuilder

Returns a builder for an animation of removing lines form a code block.

               code.remove_lines()
                   .range(0..25)
                   .over(5.s())
                   .style(CodeAnimationStyle::TypeWriter),

Methods from Deref<Target = AnimObj>

pub fn instantiate(&self) -> AnimOP

Returns an animation that instantly adds that object to the scene.

let pointer = svg()
    .path("./pointer-tool.svg")
    .build();
Project {
   scene_settings,
   timeline: timeline![
       cw.instantiate(),
    ]
}