pub struct CodeWindowHandle(pub AnimObj);Expand description
Wrapper around the AnimObj struct that allows for clean animation construction for specific
AnimObj kind.
Tuple Fields
0: AnimObjImplementations
Sourceimpl CodeWindowHandle
impl CodeWindowHandle
Sourcepub fn instantiate(&self) -> AnimOP
pub fn instantiate(&self) -> AnimOP
Returns an animation that instantly adds that object to the scene.
let pointer = svg()
.path("./pointer-tool.svg")
.build();
Project {
scene_settings,
timeline: timeline![
cw.instantiate(),
]
}Sourcepub const fn add_lines(&self) -> CodeAddLinesBuilder
pub const fn add_lines(&self) -> CodeAddLinesBuilder
Returns a builder for an animation of adding code lines to the code block.
code.add_lines()
.str(
r"
fn fib(n: u32) -> u32 {
match n {
0 => 0,
1 => 1,
_ => fib(n - 1) + fib(n - 2),
}
}
"
)
.over(5.s())
.style(CodeAnimationStyle::TypeWriter),Sourcepub const fn modify_line(&self, line: u32) -> CodeModifyLineBuilder
pub const fn modify_line(&self, line: u32) -> CodeModifyLineBuilder
Returns a builder for an animation of modifying a line of code.
code.modify_line()
.str("New Line Contents")
.line(25)
.over(5.s())
.style(CodeAnimationStyle::TypeWriter),Sourcepub fn highlight(&self) -> CodeHighlightBuilder
pub fn highlight(&self) -> CodeHighlightBuilder
Returns a builder for an animation of highlighting code by line range or regex pattern.
cw.highlight()
.lines(3..6)
.color(Color::new(1.0, 1.0, 0.0, 0.3))
.over(1.s())
.ease(Ease::InOutCubic),Sourcepub const fn remove_lines(&self, range: Range<u32>) -> CodeRemoveLinesBuilder
pub const fn remove_lines(&self, range: Range<u32>) -> CodeRemoveLinesBuilder
Returns a builder for an animation of removing lines form a code block.
code.remove_lines()
.range(0..25)
.over(5.s())
.style(CodeAnimationStyle::TypeWriter),Returns handle to one of the objects that are used inside of the code window. This allows you to animate them or use the as a reference point for movement.
Returns handle to one of the objects that are used inside of the code window. This allows you to animate them or use the as a reference point for movement.
Returns handle to one of the objects that are used inside of the code window. This allows you to animate them or use the as a reference point for movement.
Sourcepub const fn title_text(&self) -> TextHandle
pub const fn title_text(&self) -> TextHandle
Returns handle to one of the objects that are used inside of the code window. This allows you to animate them or use the as a reference point for movement.
Sourcepub const fn window_background(&self) -> RectangleHandle
pub const fn window_background(&self) -> RectangleHandle
Returns handle to one of the objects that are used inside of the code window. This allows you to animate them or use the as a reference point for movement.
Sourcepub const fn container(&self) -> RectangleHandle
pub const fn container(&self) -> RectangleHandle
Returns handle to one of the objects that are used inside of the code window. This allows you to animate them or use the as a reference point for movement.
Sourcepub const fn title_bar_background(&self) -> RectangleHandle
pub const fn title_bar_background(&self) -> RectangleHandle
Returns handle to one of the objects that are used inside of the code window. This allows you to animate them or use the as a reference point for movement.
Methods from Deref<Target = AnimObj>
Sourcepub fn instantiate(&self) -> AnimOP
pub fn instantiate(&self) -> AnimOP
Returns an animation that instantly adds that object to the scene.
let pointer = svg()
.path("./pointer-tool.svg")
.build();
Project {
scene_settings,
timeline: timeline![
cw.instantiate(),
]
}