pub struct TextHandle(pub Uuid);Expand description
Handle to a Text sub-object of a code window, for use in animation builders.
Tuple Fields
0: UuidImplementations
Sourceimpl TextHandle
impl TextHandle
Sourcepub const fn position(&self) -> PositionBuilder
pub const fn position(&self) -> PositionBuilder
Returns a builder for an animation that moves this object to a target position.
handle.position()
.to(Vec2::new(100.0, 200.0))
.over(5.s())
.ease(Ease::InOutCubic),Sourcepub const fn scale(&self) -> ScaleBuilder
pub const fn scale(&self) -> ScaleBuilder
Returns a builder for an animation that scales this object.
handle.scale()
.to(Vec2::new(2.0, 2.0))
.over(5.s())
.ease(Ease::InOutCubic),Sourcepub const fn rotation(&self) -> RotateBuilder
pub const fn rotation(&self) -> RotateBuilder
Returns a builder for an animation that rotates this object.
handle.rotation()
.to(360.0)
.over(5.s())
.ease(Ease::InOutCubic),Trait Implementations
Sourceimpl From<TextHandle> for Uuid
impl From<TextHandle> for Uuid
Sourcefn from(h: TextHandle) -> Uuid
fn from(h: TextHandle) -> Uuid
Converts to this type from the input type.