pub struct Camera {
pub dirty: bool,
pub virtual_size: Vec2,
pub position: Vec2,
pub zoom: f32,
}Expand description
Camera LOL
Fields
dirty: boolMakes the renderer write camera’s matrix into buffer
virtual_size: Vec2For example, if the virtual_size= 1080 then objects with transform at y= 540 will be at the center of your screen no mater the render resolution.
position: Vec2Offsets the whole scene
zoom: f32Zooms in on the whole scene
Implementations
Sourceimpl Camera
impl Camera
Sourcepub const fn new(virtual_size: Vec2, position: Vec2, zoom: f32) -> Self
pub const fn new(virtual_size: Vec2, position: Vec2, zoom: f32) -> Self
virtual_size- Size of the space that is used in animations.
For example, if the virtual_size= 1080 then objects with transform at y= 540 will be at the
center of your screen no mater the render resolution.
position- Offsets the whole scene
zoom- Zooms in on the whole scene
Sourcepub fn get_matrix(&self) -> Mat4
pub fn get_matrix(&self) -> Mat4
Internal function go the projection matrix