Structs
- Position
Builder - Builder for an animation that moves an object to a target position
- Rotate
Builder - Builder for an animation that rotates an object
- Scale
Builder - Builder for an animation that scales an object
- Transform
- The transform of an object, containing its position, rotation, and scale.