Transform

Struct Transform 

pub struct Transform {
    pub uuid: Uuid,
    pub parent: Option<Uuid>,
    pub position: Vec3,
    pub rotation: f32,
    pub scale: Vec2,
}
The transform of an object, containing its position, rotation, and scale.

Fields

uuid: Uuid

Unique identifier for this transform

parent: Option<Uuid>

Optional parent transform UUID for hierarchical transforms

position: Vec3

3D position of the object (z is used for draw ordering)

rotation: f32

Rotation of the object in degrees

scale: Vec2

Uniform or nonuniform scale of the object

Implementations

Source

impl Transform

pub fn new(position: Vec3) -> Self

Create a new transform at the given position. A random UUID is generated for identification.

pub const fn with_parent(self, parent: Uuid) -> Self

Set the parent of this transform

pub const fn position(&self) -> PositionBuilder

Returns a builder for an animation that moves this object to a new position.

               transform.position()
                   .to(Vec2::new(100.0, 200.0))
                   .over(5.s())
                   .ease(Ease::InOutCubic),
pub const fn scale(&self) -> ScaleBuilder

Returns a builder for an animation that scales this object.

               transform.scale()
                   .to(Vec2::new(2.0, 2.0))
                   .over(5.s())
                   .ease(Ease::InOutCubic),
pub const fn rotation(&self) -> RotateBuilder

Returns a builder for an animation that rotates this object.

               transform.rotation()
                   .to(360.0)
                   .over(5.s())
                   .ease(Ease::InOutCubic),