pub struct CodeRemoveLinesBuilder { /* private fields */ }Expand description
Builder for an animation of removing lines from a code block.
code.remove_lines()
.range(0..25)
.over(5.s())
.style(CodeAnimationStyle::TypeWriter),Implementations
Sourceimpl CodeRemoveLinesBuilder
impl CodeRemoveLinesBuilder
Sourcepub const fn over(self, duration: Time) -> Self
pub const fn over(self, duration: Time) -> Self
Duration that you want to be animating the removal over
Sourcepub const fn ease(self, ease: Ease) -> Self
pub const fn ease(self, ease: Ease) -> Self
Ease function that you want to use on this animation
Sourcepub const fn style(self, style: CodeAnimationStyle) -> Self
pub const fn style(self, style: CodeAnimationStyle) -> Self
Style of the code animation